setwd("/Users/sebastian/git/server.sbaltes.com/projects/snippets/limitations")

# read data
library(data.table)
referenced_answers <- fread(file="PostReferenceGH_Answers_R.csv", header=TRUE, sep=",", quote="\"", strip.white=TRUE, showProgress=TRUE, encoding="UTF-8", na.strings=c(""), stringsAsFactors=FALSE)
referenced_java_answers <- referenced_answers[!is.na(referenced_answers$FileExt) & referenced_answers$FileExt == ".java",]
all_java_answers <- fread(file="so_java_answers.csv", header=TRUE, sep=",", quote="\"", strip.white=TRUE, showProgress=TRUE, encoding="UTF-8", na.strings=c(""), stringsAsFactors=FALSE)

# aggregate by PostId
library(sqldf)
referenced_java_answers_postid <- sqldf("SELECT PostId, COUNT(DISTINCT FileId) as FileIdCount, CommentCount, Score, ParentViewCount FROM referenced_java_answers GROUP BY PostId")

all_java_answers_referenced <- all_java_answers[all_java_answers$post_id %in% referenced_java_answers_postid$PostId,]
all_java_answers_not_referenced <- all_java_answers[!all_java_answers$post_id %in% referenced_java_answers_postid$PostId,]

wilcox.test(all_java_answers_referenced$score, all_java_answers_not_referenced$score, alternative="two.sided", paired=F, correct=T) # Wilcoxon rank sum test (equivalent to the Mann-Whitney test), exact distribution (Streitberg-Roehmel algorithm) => handles ties
# W = 9705800000, p-value < 2.2e-16
# alternative hypothesis: true location shift is not equal to 0

summary(all_java_answers_referenced$score)
# Min.  1st Qu.   Median     Mean  3rd Qu.     Max. 
# -3.00     7.00    25.00    95.33    74.50 25400.00 
nrow(all_java_answers_referenced)
# 3,051
sd(all_java_answers_referenced$score)
# 511.5467

summary(all_java_answers_not_referenced$score)
# Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# -52.00    0.00    1.00    2.48    2.00 8643.00 
nrow(all_java_answers_not_referenced)
# 3,409,516
sd(all_java_answers_not_referenced$score)
# 16.69292

quartz(type="pdf", file="score-boxplot.pdf", width=12, height=5) # prevents unicode issues in pdf
#pdf("score-boxplot.pdf", bg="transparent", width=12, height=5, encoding="utf8")
par(
  bg="white",
  #mar = c(1.2, 1.0, 0.1, 0.0)+0.1, # subplot margins (bottom, left, top, right)
  #omi = c(0.2, 0.5, 0.0, 0.0)+0.1,  # outer margins in inches (bottom, left, top, right)
  mfrow = c(1, 1),
  #pin = (width, height)
  #mfcol # draw in columns
  # increase font size
  cex=1.3,
  cex.main=1.3,
  cex.sub=1.3,
  cex.lab=1.3,
  cex.axis=1.3
)

scores = list(all_java_answers_not_referenced$score, all_java_answers_referenced$score)
names(scores) <- c("Not ref.", "Ref.")
boxplot(scores,
        main="Score of referenced (n=3,051) vs. not referenced (n=3.4m) SO Java answers",
        outline=FALSE,
        horizontal=TRUE,
        ylim=c(0, 180),
        xaxt="n"
)
axis(1, at=seq(0, 180, by=20), labels=seq(0, 180, by=20))

# reset plot layout
par(mfrow = c(1, 1))
dev.off()



view_counts = list(all_java_answers_not_referenced$parent_view_count, all_java_answers_referenced$parent_view_count)
names(view_counts) <- c("Unreferenced", "Referenced")
boxplot(view_counts,
        main="View count of referenced (n=3,051) vs. not referenced (n=3.4m) SO Java answers",
        outline=FALSE,
        horizontal=TRUE,
        ylim=c(0, 200000),
        xaxt="n"
)
axis(1, at=seq(0, 200000, by=20000), labels=seq(0, 200000, by=20000))

comment_counts = list(all_java_answers_not_referenced$comment_count, all_java_answers_referenced$comment_count)
names(comment_counts) <- c("Unreferenced", "Referenced")
boxplot(comment_counts,
        main="Comment count of referenced (n=3,051) vs. not referenced (n=3.4m) SO Java answers",
        outline=FALSE,
        horizontal=TRUE,
        ylim=c(0, 20)
        #xaxt="n"
)
axis(1, at=seq(0, 20, by=5), labels=seq(0, 20, by=5))

